/***************************************************************************
 *  Statusled ist jeweils eine 2-PIN-Duo-LED
 * 	4 - Zustnde:
 *		OFF 	Beide Pins aus
 *		GREEN	PinA = ON, PinB = OFF
 *		RED		PinA = OFF, PinB = ON
 *		YELLOW	Schneller Wechsel von RED/GREEN
 ***************************************************************************/
#include <inttypes.h>
#include <avr/io.h>

#include "portconfig.h";
#include "timer.h";
#include "led.h";

/***************************************************************************
 * 
 * Initialisierung
 * Ausgnge setzen, LEDs aus
 * 
 ***************************************************************************/
void led_Init(void)
{
	//Ports als Output setzen
	DDRA = (1<<LED1_PIN_G)|(1<<LED1_PIN_R)|(1<<LED2_PIN_G)|(1<<LED2_PIN_R);

	//Interne Pullups OFF
	//...
	
	led1_status = LEDOFF;
	led2_status = LEDOFF;

	led_Refresh();
}

/***************************************************************************
 * 
 * Status fr eine LED setzen
 * PinG 	Pin Grn
 * PinR		Pin Rot
 * status	Anzeigestatus
 * 
 ***************************************************************************/
void led_SetStatus(uint8_t PinG,uint8_t  PinR,uint8_t  status)
{
	switch (status) 
    {
        case LEDOFF: 	break;

        case LEDGREEN:	PORTA |= (1<<PinG); break;
        case LEDRED:	PORTA |= (1<<PinR); break;

		//grn blinkend: 1Khz/1024=1Hz
		case LEDBGREEN:	if (Timer0_Count>1024) PORTA |= (1 << PinG); break; 
		case LEDBRED:	if (Timer0_Count>1024) PORTA |= (1 << PinR); break; 

        case LEDYELLOW:	
			if ((Timer0_Count & 1)==0) //LED wechselt mit 1kHz zw. Rot und Gruen => Gelb
				PORTA |= (1<<PinG);
			else
				PORTA |= (1<<PinR); 
            break;

        case LEDBYELLOW:	
			if (Timer0_Count>1024)
			{
				if ((Timer0_Count & 1)==0) //LED wechselt mit 1kHz zw. Rot und Gruen => Gelb
					PORTA |= (1<<PinG);
				else
					PORTA |= (1<<PinR); 
            	break;
			}
    }
}

/***************************************************************************
 * 
 * LED-Anzeige aktualisieren
 * 
 ***************************************************************************/
void led_Refresh(void)
{
	//LED 1
	PORTA	=	0; //Alles Aus
	led_SetStatus(LED1_PIN_G, LED1_PIN_R, led1_status);
	led_SetStatus(LED2_PIN_G, LED2_PIN_R, led2_status);
}


