#include <inttypes.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/signal.h>

#include "portconfig.h";
#include "led.h";
#include "pwm.h";
#include "timer.h"
#include "button.h"
#include "akku.h"
#include "globals.h"

void init(void);

/***************************************************************************
 * 
 * Counter0 Interrupt
 * 
 * f=1Khz
 *
 ***************************************************************************/
SIGNAL(SIG_OVERFLOW0)
{
 	uint8_t button_status;
	uint8_t akku_status;

	//Zustzlicher Taktdivider, u.a. fr Blinken der LEDs
	if (++Timer0_Count == 500) 
		Timer0_Count = 0;
	
	//Tastendruck auswerten
	button_status = button_GetStatus();
	switch (button_status)
	{
		case BPRESSED: 	
			if (++controller_status==STAT_HAL100) 
				controller_status=STAT_HAL50;
		break;

		case BLPRESSED:
			switch (controller_status)
			{
				case STAT_HAL100: 	controller_status = STAT_LED; break;
				case STAT_HAL50: 	controller_status = STAT_LED; break;
				case STAT_LED: 		controller_status = STAT_OFF; break;
			}
		break;
	}

	//Akkustand messen
	akku_status = akku_GetStatus();

	//Akkustatusled
	switch (akku_status)
	{
		case 0:		led2_status = LEDBRED; 		break;
		case 1:				led2_status = LEDRED; 		break;
		case 2:				led2_status = LEDBYELLOW; 	break;
		case 3:				led2_status = LEDYELLOW; 	break;
		case 4:				led2_status = LEDBGREEN; 	break;
		case 5:				led2_status = LEDGREEN; 	break;
	}
	
	//Statusled fr den Lampenstatus 	
	switch (controller_status)
	{
		case STAT_OFF:				break;
		case STAT_LED:		led1_status = LEDOFF;		break;
		case STAT_HAL50:	led1_status = LEDOFF;		break;
		case STAT_HAL100:	led1_status = LEDOFF;		break;
	}

	//LED-Anzeige aktualisieren
	led_Refresh();

	//PWM-Ausgnge setzen
	PWM_CHANNEL_1 = lamp1_pwmlevels[controller_status];
	PWM_CHANNEL_2 = lamp2_pwmlevels[controller_status];
}

/***************************************************************************
 * 
 * Initialization
 * 
 ***************************************************************************/
void init(void)
{
	led_Init();
	pwm_Init();
	timer_Init();
	adc_Init();
	button_Init();
	controller_status = STAT_OFF;
}

/***************************************************************************
 * 
 * Initialization
 * 
 ***************************************************************************/
int main(void)
{
	init();
  	sei();	//Enable Interrupts 

	while (1)
		;

	return 0;
}
